@@ -288,12 +288,18 @@ int DoOneExperiment (PEXPERIMENT pexp)
       /* dTime == dTtrans <= dTout: we are at a discontinuity.
          This point belongs to the NEW period UNLESS we are at
          the final time */
-      if (dTtrans < pexp->dTfinal) {
-        CorrectInputToTransition (pexp, &dTtrans);
-        pis->iDSFlag = 1;
+      if (dTtrans < dTout) {
+        if (dTtrans < pexp->dTfinal) {
+          CorrectInputToTransition (pexp, &dTtrans);
+          pis->iDSFlag = 1;
+        }
       }
-
-      if (dTtrans == dTout) {
+      else {
+        /* dTtrans == dTout */
+        if (dTtrans < pexp->dTfinal) {
+          CorrectInputToTransition (pexp, &dTtrans);
+          pis->iDSFlag = 1;
+        }
         SaveOutputs (pexp, &dTout);
         NextOutputTime (pexp, &dTout, &iOut);
       }
